==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>končit nynější hru?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pozastaveno&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klepněte pro pokračování ve hře.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Konec hry&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klepněte pro spuštění nové hry.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte, prosím, tento program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Výsledky</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Řádky</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klepněte pro spuštění nové hry.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastavit</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>P&amp;okračovat</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Výsledky</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>J&amp;azyk programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O &amp;programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Další kousek</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Odstraněné řádky</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O hře</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Klon tetrisu, který Graeme udělal pro svou ženu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Autorské právo &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>končit nynější hru?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Pozastaveno&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klepněte pro pokračování ve hře.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Konec hry&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klepněte pro spuštění nové hry.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte, prosím, tento program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Řádky</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klepněte pro spuštění nové hry.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastavit</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Výsledky</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>J&amp;azyk programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O &amp;programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Další kousek</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Odstraněné řádky</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O hře</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Autorské právo &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
